@@ -674,6 +674,8 @@ class Aperture(_BaseWithShade):
         Returns:
             True if geometrically equivalent. False if not geometrically equivalent.
         """
+        if abs(self.area - aperture.area) > tolerance * self.area:
+            return False
         return self.geometry.is_centered_adjacent(aperture.geometry, tolerance)
 
     def check_planar(self, tolerance=0.01, raise_exception=True, detailed=False):
